import { GraphQLSchema, ValidationContext, GraphQLFieldResolver } from 'graphql';
import { PersistedQueryCache, HttpHeaderCalculation } from './caching';
import { GraphQLExtension } from 'graphql-extensions';
import { RESTDataSource, KeyValueCache } from 'apollo-datasource-rest';
import { CacheControlExtensionOptions } from 'apollo-cache-control';
export interface GraphQLServerOptions<TContext = (() => Promise<Record<string, any>> | Record<string, any>) | Record<string, any>> {
    schema: GraphQLSchema;
    formatError?: Function;
    rootValue?: any;
    context?: TContext;
    formatParams?: Function;
    validationRules?: Array<(context: ValidationContext) => any>;
    formatResponse?: Function;
    fieldResolver?: GraphQLFieldResolver<any, TContext>;
    debug?: boolean;
    tracing?: boolean;
    cacheControl?: boolean | (CacheControlExtensionOptions & {
        calculateHttpHeaders?: boolean | HttpHeaderCalculation;
        stripFormattedExtensions?: boolean;
    });
    extensions?: Array<() => GraphQLExtension>;
    dataSources?: () => DataSources;
    cache?: KeyValueCache;
    persistedQueries?: PersistedQueryOptions;
}
export declare type DataSources = {
    [name: string]: RESTDataSource;
};
export interface PersistedQueryOptions {
    cache: PersistedQueryCache;
}
export default GraphQLServerOptions;
export declare function resolveGraphqlOptions(options: GraphQLServerOptions | ((...args: Array<any>) => Promise<GraphQLServerOptions> | GraphQLServerOptions), ...args: Array<any>): Promise<GraphQLServerOptions>;
//# sourceMappingURL=graphqlOptions.d.ts.map